==> maildrop_0.75.orig.tar.gz: maildrop-0.75/maildrop/acconfig.h <==
/* DSTART                                                                    */
/*                                                                           */
/*           maildrop - mail delivery agent with filtering abilities         */
/*                                                                           */
/*  Copyright 1998-1999, Double Precision Inc.                               */
/*                                                                           */
/*  This program is distributed under the terms of the GNU General Public    */
/*  License. See COPYING for additional information.                         */
/* DEND                                                                      */
/* $Id: acconfig.h,v 1.4 1999/09/10 02:10:05 mrsam Exp $ */

/* Our package */
#undef PACKAGE

/* Our version */
#undef VERSION

/* maildrop setuid */
#undef MAILDROPUID

/* maildrop setgid */
#undef MAILDROPGID

/* Set to 1 if we have the flock() system call */
#define	HAS_FLOCK		1

/* Set to 1 if we have the lockf() system call */
#define	HAS_LOCKF		1

/* Set to 1 if we have the setpgrp() system call */
#define	HAS_SETPGRP		1

/* Set to 1 if we have the setpgid() system call */
#define	HAS_SETPGID		1

/* Set to 1 if we have the getpgrp() system call */
#define	HAS_GETPGRP		1

/* Set to 1 if we have the getpgid() system call */
#define	HAS_GETPGID		1


/* Location of the default mailbox */
#define DEFAULT_DEF "/var/spool/mail"

/* Permissions on mailbox files */
#define MAILBOX_MODE 0600

/* Whether maildrop should immediately drop set-group-id privileges on startup */
#define RESET_GID 1

/* Define default value for PATH - path for executed commands */
#define DEFAULT_PATH "/usr/bin:/usr/local/bin"

/* Define location of the mail transport agent (sendmail) */
#define SENDMAIL_DEF "/usr/lib/sendmail"

/* The -d option is restricted to the following users, if so desired at compile time. */
#define TRUSTED_USERS "root"

/* Whether unistd.h includes a prototype for gethostname */
#undef	HAS_GETHOSTNAME

/* Whether fatal errors should be logged via syslog() */
#define	SYSLOG_LOGGING	0

/* Whether we have -lgdbm */
#undef	HAVE_LIBGDBM

/* Maximum size of a LONG, in bytes */
#undef	MAXLONGSIZE

/* Location of the /etc directory */
#undef	ETCDIR

/* Whether maildir quota feature is enabled */
#undef	MAILDIRQUOTA

/* Whether virtual user database feature is enabled */
#undef	USERDB

/* Define this if we need both catch(const foo) and catch(foo) */
#undef	NEED_NONCONST_EXCEPTIONS

/* Define this if to use tmpfile() instead of creating files in ~/.tmp */
#undef	SHARED_TEMPDIR

==> maildrop-1.2.2.tar.gz: maildrop-1.2.2/maildrop/acconfig.h <==
/* $Id: acconfig.h,v 1.7 2000/04/28 17:17:45 mrsam Exp $ */

/* Our package */
#undef PACKAGE

/* Our version */
#undef VERSION

/* maildrop setuid */
#undef MAILDROPUID

/* maildrop setgid */
#undef MAILDROPGID

/* Set to 1 if we have the setpgrp() system call */
#define	HAS_SETPGRP		1

/* Set to 1 if we have the setpgid() system call */
#define	HAS_SETPGID		1

/* Set to 1 if we have the getpgrp() system call */
#define	HAS_GETPGRP		1

/* Set to 1 if we have the getpgid() system call */
#define	HAS_GETPGID		1


/* Location of the default mailbox */
#define DEFAULT_DEF "/var/spool/mail"

/* Permissions on mailbox files */
#define MAILBOX_MODE 0600

/* Whether maildrop should immediately drop set-group-id privileges on startup */
#define RESET_GID 1

/* Define default value for PATH - path for executed commands */
#define DEFAULT_PATH "/usr/bin:/usr/local/bin"

/* Define location of the mail transport agent (sendmail) */
#define SENDMAIL_DEF "/usr/lib/sendmail"

/* The -d option is restricted to the following users, if so desired at compile time. */
#define TRUSTED_USERS "root"

/* Alternatively, the -d option can be restricted to the following groups, if so desired at compile time. */
#undef	TRUSTED_GROUPS

/* Whether unistd.h includes a prototype for gethostname */
#undef	HAS_GETHOSTNAME

/* Whether fatal errors should be logged via syslog() */
#define	SYSLOG_LOGGING	0

/* Whether we have -lgdbm */
#undef	HAVE_LIBGDBM

/* Maximum size of a LONG, in bytes */
#undef	MAXLONGSIZE

/* Location of the /etc directory */
#undef	ETCDIR

/* Whether maildir quota feature is enabled */
#undef	MAILDIRQUOTA

/* Whether virtual user database feature is enabled */
#undef	USERDB

/* Define this if we need both catch(const foo) and catch(foo) */
#undef	NEED_NONCONST_EXCEPTIONS

/* Define this if to use tmpfile() instead of creating files in ~/.tmp */
#undef	SHARED_TEMPDIR

/* Whether this version of maildrop is integrated into Courier */
#undef	HAVE_COURIER
